/*
 *     file: RegexFilterMode.java
 *  package: org.eclipse.regex.tools.ui
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.regex.tools.ui;

import java.io.Serializable;

/**
 * An enumeration type for describing various modes used by
 * <code>RegexPatternSetViewFilter</code>.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.regex.tools.plugin.ui.RegexPatternSetViewFilter
 */
public final class RegexFilterMode implements Serializable {

    /** Filter out if any pattern matches the input. */
    public final static RegexFilterMode FILTER_OUT_ON_ANY = new RegexFilterMode("FILTER_OUT_ON_ANY"); //$NON-NLS-1$

    /** Filter out only when all patterns match the input.. */
    public final static RegexFilterMode FILTER_OUT_ON_ALL = new RegexFilterMode("FILTER_OUT_ON_ALL"); //$NON-NLS-1$

    /** Don't filter if any pattern matches the input. */
    public final static RegexFilterMode FILTER_IN_ON_ANY = new RegexFilterMode("FILTER_IN_ON_ANY"); //$NON-NLS-1$

    /** Don't filter only when all patterns match the input.. */
    public final static RegexFilterMode FILTER_IN_ON_ALL = new RegexFilterMode("FILTER_IN_ON_ALL"); //$NON-NLS-1$

    /** The name of the filter mode. */
    final String name;

    /**
     * Creates a new <code>RegexFilterMode</code> with the given parameters.
     * 
     * @param name The name of the filter mode.
     */
    private RegexFilterMode(final String name) {
        this.name = name;
    }

    /**
     * Getter for name: The name of the filter mode.
     * 
     * @return Returns the name.
     */
    public String getName() {
        return this.name;
    }

    /**
     * Resolve serialized reads.
     * 
     * @param readObject The object read.
     * @return The resolved object.
     */
    public Object readResolve(final Object readObject) {
        final RegexFilterMode modeRead = (RegexFilterMode)readObject;
        if (modeRead.getName().equals(RegexFilterMode.FILTER_OUT_ON_ANY.getName())) {
            return RegexFilterMode.FILTER_OUT_ON_ANY;
        } else if (modeRead.getName().equals(RegexFilterMode.FILTER_OUT_ON_ANY.getName())) {
            return RegexFilterMode.FILTER_OUT_ON_ANY;
        } else if (modeRead.getName().equals(RegexFilterMode.FILTER_IN_ON_ANY.getName())) {
            return RegexFilterMode.FILTER_IN_ON_ANY;
        } else if (modeRead.getName().equals(RegexFilterMode.FILTER_IN_ON_ALL.getName())) {
            return RegexFilterMode.FILTER_IN_ON_ALL;
        }
        throw new AssertionError(I18N.ERR_UNEXPECTED_BRANCH);
    }
}

/* ########## End of File ########## */