/*
 *     file: StackTraceContentProvider.java
 *  package: org.eclipse.swt.sleak.plugin.views
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.views;

import org.eclipse.jface.viewers.IStructuredContentProvider;
import org.eclipse.jface.viewers.Viewer;

/**
 * A content provider for the SLeak Stack trace panel.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 */
public class StackTraceContentProvider implements IStructuredContentProvider {

    /**
     * Assumes the input object is an array of stack trace elements.
     * 
     * @param inputElement The input element of the viewer.
     * @see org.eclipse.jface.viewers.IStructuredContentProvider#getElements(java.lang.Object)
     */
    public Object[] getElements(final Object inputElement) {
        if (null == inputElement) {
            return new StackTraceElement [0];
        }
        final StackTraceElement[] elements = (StackTraceElement[])inputElement;

        // -- return the list of elements.
        return elements;
    }

    /**
     * @see org.eclipse.jface.viewers.IContentProvider#dispose()
     */
    public void dispose() {
        // nothing needed at present
    }

    /**
     * @see org.eclipse.jface.viewers.IContentProvider#inputChanged(org.eclipse.jface.viewers.Viewer,
     *      java.lang.Object, java.lang.Object)
     */
    public void inputChanged(final Viewer viewer, final Object oldInput, final Object newInput) {
        // nothing needed.
    }
}

/* ########## End of File ########## */