/*
 *     file: I18N.java
 *  package: org.eclipse.regex.tools.ui
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.regex.tools.ui;

import java.util.ResourceBundle;

/**
 * Contains constants for Strings used for internationalization.
 * <p>
 * Note that the person translator need only submit a new I18N.properties file in this
 * package for the appropriate locale according to the
 * <code>java.util.ResourceBundle</code> documentation. The main usage of this file for
 * the translator is in seeing the context of the string constants. Each constant is
 * commented according to how it is used.
 * </p>
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see java.util.ResourceBundle
 */
final class I18N {

    // ---------------- Error Messages ----------------

    /** Error for when unexpected code branches are encountered. */
    public final static String ERR_UNEXPECTED_BRANCH;

    /** Error for when there is an invalid element in a set. */
    public final static String ERR_INVALID_ELEMENT;

    // ---------------- General Strings ----------------

    /** Tooltip text for the table of patterns. */
    public final static String TOOLTIP_PATTERN_TABLE;

    /** Column title for flags column. */
    public final static String COL_FLAGS;

    /** Column title for patterns column. */
    public final static String COL_PATTERNS;

    /** Message for successful validation. */
    public final static String MXG_REGEX_VALID;

    /** Label for the add pattern button. */
    public final static String BTN_ADD_PATTERN;

    /** Label for the remove pattern button. */
    public final static String BTN_REMOVE_PATTERN;

    /** Title for the regex validation message dialog. */
    public final static String TITLE_DLG_REGEX_VALID;

    /** Label for a checkbox for regex pattern case insensitivity. */
    public final static String CHK_CASE_INSENSITIVE;

    /** Tooltip text for a checkbox for regex pattern case insensitivity. */
    public final static String TOOLTIP_CASE_INSENSITIVE;

    /** Label for a checkbox for regex pattern canonical equivalence. */
    public final static String CHK_CANON_EQ;

    /** Tooltip text for a checkbox for regex pattern canonical equivalence. */
    public final static String TOOLTIP_CANON_EQ;

    /** Label for a checkbox for regex pattern comments mode. */
    public final static String CHK_COMMENTS;

    /** Tooltip text for a checkbox for regex pattern comments mode. */
    public final static String TOOLTIP_COMMENTS;

    /** Label for a checkbox for regex pattern dotall mode. */
    public final static String CHK_DOTALL;

    /** Tooltip text for a checkbox for regex pattern dotall mode. */
    public final static String TOOLTIP_DOTALL;

    /** Label for a checkbox for regex pattern multiline mode. */
    public final static String CHK_MULTILINE;

    /** Tooltip text for a checkbox for regex pattern multiline mode. */
    public final static String TOOLTIP_MULTILINE;

    /** Label for a checkbox for regex pattern unicode case folding mode. */
    public final static String CHK_UNICODE_CASE;

    /** Tooltip text for a checkbox for regex pattern unicode case folding mode. */
    public final static String TOOLTIP_UNICODE_CASE;

    /** Label for a checkbox for regex pattern unix lines mode. */
    public final static String CHK_UNIX_LINES;

    /** Tooltip text for a checkbox for regex pattern unix lines mode. */
    public final static String TOOLTIP_UNIX_LINES;

    /** Label for the defaults button in the regexp pattern editor. */
    public final static String BTN_DEFAULTS;

    /** Tooltip text for the defaults button in the regexp pattern editor. */
    public final static String TOOLTIP_DEFAULTS;

    /** Tooltip text for the regex pattern entry field. */
    public final static String TOOLTIP_PATTERN_FIELD;

    /** Tooltip text for the regex pattern validation button. */
    public final static String TOOLTIP_VALIDATE_BTN;

    static {
        final String bundleName = I18N.class.getName(); //$NON-NLS-1$
        final ResourceBundle bundle = ResourceBundle.getBundle(bundleName);

        ERR_UNEXPECTED_BRANCH = bundle.getString("ERR_UNEXPECTED_BRANCH"); //$NON-NLS-1$
        ERR_INVALID_ELEMENT = bundle.getString("ERR_INVALID_ELEMENT"); //$NON-NLS-1$

        TOOLTIP_PATTERN_TABLE = bundle.getString("TOOLTIP_PATTERN_TABLE"); //$NON-NLS-1$
        COL_FLAGS = bundle.getString("COL_FLAGS"); //$NON-NLS-1$
        COL_PATTERNS = bundle.getString("COL_PATTERNS"); //$NON-NLS-1$
        MXG_REGEX_VALID = bundle.getString("MXG_REGEX_VALID"); //$NON-NLS-1$
        BTN_ADD_PATTERN = bundle.getString("BTN_ADD_PATTERN"); //$NON-NLS-1$
        BTN_REMOVE_PATTERN = bundle.getString("BTN_REMOVE_PATTERN"); //$NON-NLS-1$
        TITLE_DLG_REGEX_VALID = bundle.getString("TITLE_DLG_REGEX_VALID"); //$NON-NLS-1$
        CHK_CASE_INSENSITIVE = bundle.getString("CHK_CASE_INSENSITIVE"); //$NON-NLS-1$
        TOOLTIP_CASE_INSENSITIVE = bundle.getString("TOOLTIP_CASE_INSENSITIVE"); //$NON-NLS-1$
        CHK_CANON_EQ = bundle.getString("CHK_CANON_EQ"); //$NON-NLS-1$
        TOOLTIP_CANON_EQ = bundle.getString("TOOLTIP_CANON_EQ"); //$NON-NLS-1$
        CHK_COMMENTS = bundle.getString("CHK_COMMENTS"); //$NON-NLS-1$
        TOOLTIP_COMMENTS = bundle.getString("TOOLTIP_COMMENTS"); //$NON-NLS-1$
        CHK_DOTALL = bundle.getString("CHK_DOTALL"); //$NON-NLS-1$
        TOOLTIP_DOTALL = bundle.getString("TOOLTIP_DOTALL"); //$NON-NLS-1$
        CHK_MULTILINE = bundle.getString("CHK_MULTILINE"); //$NON-NLS-1$
        TOOLTIP_MULTILINE = bundle.getString("TOOLTIP_MULTILINE"); //$NON-NLS-1$
        CHK_UNICODE_CASE = bundle.getString("CHK_UNICODE_CASE"); //$NON-NLS-1$
        TOOLTIP_UNICODE_CASE = bundle.getString("TOOLTIP_UNICODE_CASE"); //$NON-NLS-1$
        CHK_UNIX_LINES = bundle.getString("CHK_UNIX_LINES"); //$NON-NLS-1$
        TOOLTIP_UNIX_LINES = bundle.getString("TOOLTIP_UNIX_LINES"); //$NON-NLS-1$
        BTN_DEFAULTS = bundle.getString("BTN_DEFAULTS"); //$NON-NLS-1$
        TOOLTIP_DEFAULTS = bundle.getString("TOOLTIP_DEFAULTS"); //$NON-NLS-1$
        TOOLTIP_PATTERN_FIELD = bundle.getString("TOOLTIP_PATTERN_FIELD"); //$NON-NLS-1$
        TOOLTIP_VALIDATE_BTN = bundle.getString("TOOLTIP_VALIDATE_BTN"); //$NON-NLS-1$
    }
}

/* ########## End of File ########## */