/*
 *     file: DeltaDeviceDataCache.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

import java.util.Iterator;
import java.util.SortedSet;
import java.util.TreeSet;

/**
 * Default implementation of <code>IDeltaDeviceDataCache</code>.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.core.IDeltaDeviceDataCache
 */
class DeltaDeviceDataCache extends DeviceDataCache implements IDeltaDeviceDataCache {

    /** The before view of the cache. */
    final IDeviceDataCache before;

    /** The after view of of the cache. */
    final IDeviceDataCache after;

    /**
     * Creates a new <code>DeltaDeviceDataCache</code> with the given parameters.
     * 
     * @param before The cache to start the comparison with.
     * @param after The cache to compare with (must be of a later creation time).
     * @throws IllegalArgumentException if the creation data of <code>after</code> is
     *             not later than that of <code>before</code>.
     */
    DeltaDeviceDataCache(final IDeviceDataCache before, final IDeviceDataCache after) {
        // -- Set the before and after snapshots
        this.before = before;
        this.after = after;

        // -- Check preconditions.
        if (this.before.getCreationTime().compareTo(this.after.getCreationTime()) >= 0) {
            throw new IllegalArgumentException(I18N.ERR_CREATION_TIMES);
        }

        // -- Resolve the two snapshots and build a new cache.
        for (final Iterator iter = ObjectCategory.getAllCategories().iterator(); iter.hasNext();) {
            final ObjectCategory category = (ObjectCategory)iter.next();
            final SortedSet first = this.before.getCategory(category);
            final SortedSet second = new TreeSet(this.after.getCategory(category));
            second.removeAll(first);
            getCategoryInternal(category).addAll(second);
        }
    }

    /**
     * @see org.eclipse.swt.sleak.core.IDeltaDeviceDataCache#getAfter()
     */
    public IDeviceDataCache getAfter() {
        return this.after;
    }

    /**
     * @see org.eclipse.swt.sleak.core.IDeltaDeviceDataCache#getBefore()
     */
    public IDeviceDataCache getBefore() {
        return this.before;
    }
}

/* ########## End of File ########## */