/*
 *     file: ObjectDeviceData.java
 *  package: org.eclipse.swt.sleak.core
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.core;

/**
 * Default implementation of <code>IObjectDeviceData</code>.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.core.ObjectDeviceData
 */
class ObjectDeviceData implements Comparable, IObjectDeviceData {

    /** The category of object. */
    private final ObjectCategory category;

    /** A reference to the object that this device data refers to. */
    private final Object object;

    /** The stack trace recorded at the time the object was created. */
    private final StackTraceElement[] stackTrace;

    /**
     * @see java.lang.Comparable#compareTo(java.lang.Object)
     */
    public int compareTo(final Object obj) {
        if (!(obj instanceof ObjectDeviceData)) {
            return -1;
        }
        return getObject().hashCode() - ((IObjectDeviceData)obj).getObject().hashCode();
    }

    /**
     * Creates a new <code>ObjectDeviceData</code> with the given parameters.
     * 
     * @param object A reference to the object that this device data refers to.
     * @param stackTrace The stack trace recorded at the time the object was created.
     */
    ObjectDeviceData(final Object object, final StackTraceElement[] stackTrace) {
        this.object = object;
        this.stackTrace = new StackTraceElement [stackTrace.length];
        System.arraycopy(stackTrace, 0, this.stackTrace, 0, stackTrace.length);
        this.category = ObjectCategory.categorize(object);
    }

    /**
     * Getter for category: The category of object.
     * 
     * @return Returns the category.
     */
    public ObjectCategory getCategory() {
        return this.category;
    }

    /**
     * Getter for object: A reference to the object that this device data refers to.
     * 
     * @return Returns the object.
     */
    public Object getObject() {
        return this.object;
    }

    /**
     * Getter for stackTrace: The stack trace recorded at the time the object was created.
     * 
     * @return Returns the stackTrace.
     */
    public StackTraceElement[] getStackTrace() {
        return this.stackTrace;
    }

    /**
     * @see java.lang.Object#equals(java.lang.Object) Will be equivalent when the
     *      contained objects are equivalent.
     */
    public boolean equals(final Object obj) {
        if (!(obj instanceof ObjectDeviceData)) {
            return false;
        }
        if (this == obj) {
            return true;
        }
        return this.object.equals(((ObjectDeviceData)obj).getObject());
    }

    /**
     * @see java.lang.Object#hashCode() Has the same hash code as the contained object.
     */
    public int hashCode() {
        return this.object.hashCode();
    }
}

/* ########## End of File ########## */