/*
 *     file: RemoveCache.java
 *  package: org.eclipse.swt.sleak.plugin.actions
 *
 * This software is granted under the terms of the Common Public License,
 * CPL, which may be found at the following URL:
 * http://www-124.ibm.com/developerworks/oss/CPLv1.0.htm
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.actions;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.sleak.core.ISLeak;
import org.eclipse.swt.sleak.core.ISLeakEventListener;
import org.eclipse.swt.sleak.core.SLeakEvent;
import org.eclipse.swt.sleak.plugin.SLeakPlugin;

/**
 * Running this action causes the <code>ISLeak</code> instance to delete all stored
 * caches.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.core.ISLeak
 */
public class RemoveAllCaches extends Action implements ISLeakEventListener {

    /** A cached image for this action. */
    private final static ImageDescriptor imgSnapshot = SLeakPlugin.getPluginImage("icons/remove_all_caches.gif"); //$NON-NLS-1$

    /** The S-Leak to use. */
    private final ISLeak sleak;

    /**
     * Creates a new <code>Snapshot</code> with the given parameters.
     * 
     * @param sleak The ISLeak instance on which the action can execute commands.
     */
    public RemoveAllCaches(final ISLeak sleak) {
        super(I18N.ACTION_REMOVE_ALL_CACHES, imgSnapshot);
        this.sleak = sleak;
        setToolTipText(I18N.TOOLTIP_REMOVE_ALL_CACHES); //$NON-NLS-1$
        this.sleak.addSLeakListener(this);
        setEnabled(false);
    }

    /**
     * @see org.eclipse.jface.action.IAction#run()
     */
    public void run() {
        this.sleak.clearCaches();
    }

    /**
     * @see org.eclipse.swt.sleak.core.ISLeakEventListener#doCachesUpdated(org.eclipse.swt.sleak.core.SLeakEvent)
     */
    public void doCachesUpdated(SLeakEvent event) {
        this.setEnabled(!this.sleak.isEmpty());
    }

    /**
     * @see org.eclipse.swt.sleak.core.ISLeakEventListener#doMonitorStateChanged(org.eclipse.swt.sleak.core.SLeakEvent)
     */
    public void doMonitorStateChanged(SLeakEvent event) {
        // ignore
    }
}

/* ########## End of File ########## */