/*
 *     file: RemoveCache.java
 *  package: org.eclipse.swt.sleak.plugin.actions
 *
 * This software is granted under the terms of the Common Public License,
 * CPL, which may be found at the following URL:
 * http://www-124.ibm.com/developerworks/oss/CPLv1.0.htm
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.actions;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.sleak.core.IDeviceDataCache;
import org.eclipse.swt.sleak.core.ISLeak;
import org.eclipse.swt.sleak.plugin.SLeakPlugin;

/**
 * Running this action causes the <code>ISLeak</code> instance to delete the cache
 * currently selected in the TreeViewer in the S-Leak view.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.core.ISLeak
 */
public class RemoveCache extends Action implements ISelectionChangedListener {

    /** A cached image for this action. */
    private final static ImageDescriptor imgSnapshot = SLeakPlugin.getPluginImage("icons/remove_cache.gif"); //$NON-NLS-1$

    /** The S-Leak to use. */
    private final ISLeak sleak;

    /** The S-Leak to use. */
    private final TreeViewer cacheTree;

    /**
     * Creates a new <code>Snapshot</code> with the given parameters.
     * 
     * @param sleak The ISLeak instance on which the action can execute commands.
     * @param cacheTree The tree from which the action will get the selected item.
     */
    public RemoveCache(final ISLeak sleak, final TreeViewer cacheTree) {
        super(I18N.ACTION_REMOVE_CACHE, imgSnapshot);
        this.sleak = sleak;
        this.cacheTree = cacheTree;
        this.cacheTree.addSelectionChangedListener(this);
        setToolTipText(I18N.TOOLTIP_REMOVE_CACHE); //$NON-NLS-1$
        this.setEnabled(false);
    }

    /**
     * @see org.eclipse.jface.action.IAction#run()
     */
    public void run() {
        final IStructuredSelection selection = (IStructuredSelection)this.cacheTree.getSelection();
        final Object selected = selection.getFirstElement();
        this.sleak.clearCache((IDeviceDataCache)selected);
    }

    /**
     * @see org.eclipse.jface.viewers.ISelectionChangedListener#selectionChanged(org.eclipse.jface.viewers.SelectionChangedEvent)
     */
    public void selectionChanged(final SelectionChangedEvent event) {
        if (event.getSource() == this.cacheTree) {
            final IStructuredSelection selection = (IStructuredSelection)this.cacheTree.getSelection();
            if (selection.isEmpty()) {
                this.setEnabled(false);
                return;
            }
            final Object selected = selection.getFirstElement();
            if (!(selected instanceof IDeviceDataCache)) {
                this.setEnabled(false);
                return;
            }
            this.setEnabled(true);
        } else {
            // shouldnt ever get here
            throw new AssertionError();
        }
    }

}

/* ########## End of File ########## */