/*
 *     file: StartMonitor.java
 *  package: org.eclipse.swt.sleak.plugin.actions
 *
 * This program and the accompanying materials are made available under 
 * the terms of the Common Public License v1.0 which accompanies this 
 * distribution, and is available at the following URL: 
 * http://www.eclipse.org/legal/cpl-v10.html
 *
 * Copyright(c) 2003-2005 by the authors indicated in the @author tags.
 * All Rights are Reserved by the various authors.
 *
 ########## DO NOT EDIT ABOVE THIS LINE ########## */

package org.eclipse.swt.sleak.plugin.actions;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.sleak.core.ISLeak;
import org.eclipse.swt.sleak.core.ISLeakEventListener;
import org.eclipse.swt.sleak.core.SLeakEvent;
import org.eclipse.swt.sleak.plugin.SLeakPlugin;

/**
 * Running this action tells the <code>ISLeak</code> instance to start monitoring
 * resources.
 * 
 * @author <a href=mailto:kraythe@arcor.de>Robert Simmons Jr. (Kraythe) </a>
 * @see org.eclipse.swt.sleak.plugin.actions.StartMonitor
 * @see org.eclipse.swt.sleak.core.ISLeak
 */
public class StartMonitor extends Action implements ISLeakEventListener {

    /** A cached image for this action. */
    private final static ImageDescriptor imgSnapshot = SLeakPlugin.getPluginImage("icons/start_monitor.gif"); //$NON-NLS-1$

    /** The S-Leak to use. */
    private final ISLeak sleak;

    /**
     * Creates a new <code>Snapshot</code> with the given parameters.
     * 
     * @param sleak The ISLeak instance on which the action can execute commands.
     */
    public StartMonitor(final ISLeak sleak) {
        super(I18N.ACTION_START_MONITOR, imgSnapshot);
        this.sleak = sleak;
        setToolTipText(I18N.TOOLTIP_START_MONITOR); //$NON-NLS-1$
        this.sleak.addSLeakListener(this);
    }

    /**
     * @see org.eclipse.swt.sleak.core.ISLeakEventListener#doCachesUpdated(org.eclipse.swt.sleak.core.SLeakEvent)
     */
    public void doCachesUpdated(final SLeakEvent event) {
        // ignore
    }

    /**
     * @see org.eclipse.swt.sleak.core.ISLeakEventListener#doMonitorStateChanged(org.eclipse.swt.sleak.core.SLeakEvent)
     */
    public void doMonitorStateChanged(final SLeakEvent event) {
        this.setEnabled(!event.getSource().isMonitoring());
    }

    /**
     * @see org.eclipse.jface.action.IAction#run()
     */
    public void run() {
        if (!this.sleak.isDisplayTracking()) {
            MessageDialog.openError(null, I18N.TITLE_NOT_TRACKING, I18N.MSG_NOT_TRACKING);
            return;
        }
        this.sleak.startMonitor();
    }
}

/* ########## End of File ########## */